Credits
=======

Gstore is written and maintained by `Serghei Iakovlev <https://github.com/sergeyklay/>`_.

A full list of contributors can be found in `GitHub's overview <https://github.com/sergeyklay/gstore/graphs/contributors>`_.
